@@ -110,7 +110,7 @@ pub struct Args {
 
     /// Semicolon separated commands to execute
     #[clap(short, long, value_parser)]
-    pub commands: Option<String>,
+    pub cmd: Option<String>,
 
     /// Whether to have styles and colors (auto is default and usually OK)
     #[clap(long, arg_enum, value_parser, default_value="auto")]
@@ -146,6 +146,10 @@ pub struct Args {
     #[clap(long, action)]
     pub get_root: bool,
 
+    /// Write default conf files in given directory
+    #[clap(long, value_parser)]
+    pub write_default_conf: Option<PathBuf>,
+
     /// A socket that broot sends commands to before quitting
     #[cfg(unix)]
     #[clap(long, value_parser)]
