@@ -8,7 +8,8 @@ use {
         skin::PanelSkin,
         verb::*,
     },
-    crossterm::{
+    crokey::key,
+    crokey::crossterm::{
         cursor,
         event::{
             Event,
@@ -163,7 +164,7 @@ impl PanelInput {
         key: KeyEvent,
         parts: &CommandParts,
     ) {
-        if let Some(c) = keys::as_letter(key) {
+        if let Some(c) = crokey::as_letter(key) {
             let add = match c {
                 // '/' if !parts.raw_pattern.is_empty() => true,
                 ' ' if parts.verb_invocation.is_none() => true,
@@ -222,9 +223,9 @@ impl PanelInput {
                 let mut parts = CommandParts::from(raw.clone());
 
                 // we first handle the cases that MUST absolutely
-                // not be overriden by configuration
+                // not be overridden by configuration
 
-                if key == keys::ESC {
+                if key == key!(esc) {
                     // tab cycling
                     self.tab_cycle_count = 0;
                     if let Some(raw) = self.input_before_cycle.take() {
@@ -250,7 +251,7 @@ impl PanelInput {
                 }
 
                 // tab completion
-                if key == keys::TAB {
+                if key == key!(tab) {
                     if parts.verb_invocation.is_some() {
                         let parts_before_cycle;
                         let completable_parts = if let Some(s) = &self.input_before_cycle {
@@ -298,11 +299,11 @@ impl PanelInput {
                     self.input_before_cycle = None;
                 }
 
-                if key == keys::ENTER && parts.has_not_empty_verb_invocation() {
+                if key == key!(enter) && parts.has_not_empty_verb_invocation() {
                     return Command::from_parts(parts, true);
                 }
 
-                if key == keys::QUESTION && (raw.is_empty() || parts.verb_invocation.is_some()) {
+                if key == key!('?') && (raw.is_empty() || parts.verb_invocation.is_some()) {
                     // a '?' opens the help when it's the first char
                     // or when it's part of the verb invocation
                     return Command::Internal {
@@ -327,6 +328,12 @@ impl PanelInput {
                             if mode != Mode::Input && verb.is_internal(Internal::mode_input) {
                                 self.enter_input_mode_with_key(key, &parts);
                             }
+                            if !verb.file_extensions.is_empty() {
+                                let extension = sel_info.extension();
+                                if !extension.map_or(false, |ext| verb.file_extensions.iter().any(|ve| ve == ext)) {
+                                    continue;
+                                }
+                            }
                             if verb.auto_exec {
                                 return Command::VerbTrigger {
                                     index,
