@@ -1,15 +1,15 @@
 use {
     crate::{
         app::SelectionType,
-        keys,
         command::Sequence,
         errors::ConfError,
+        keys,
         verb::*,
     },
     serde::Deserialize,
 };
 
-/// a deserializable verb entry in the configuration
+/// A deserializable verb entry in the configuration
 #[derive(Default, Debug, Clone, Deserialize)]
 pub struct VerbConf {
 
@@ -30,6 +30,9 @@ pub struct VerbConf {
     #[serde(default)]
     keys: Vec<String>,
 
+    #[serde(default)]
+    extensions: Vec<String>,
+
     shortcut: Option<String>,
 
     leave_broot: Option<bool>,
@@ -132,14 +135,17 @@ impl VerbConf {
         }
         let mut checked_keys = Vec::new();
         for key in &unchecked_keys {
-            let key = keys::parse_key(key)?;
+            let key = crokey::parse(key)?;
             if keys::is_reserved(key) {
                 return Err(ConfError::ReservedKey {
-                    key: keys::key_event_desc(key),
+                    key: keys::KEY_FORMAT.to_string(key)
                 });
             }
             checked_keys.push(key);
         }
+        for extension in &self.extensions {
+            verb.file_extensions.push(extension.clone());
+        }
         if !checked_keys.is_empty() {
             verb.add_keys(checked_keys);
         }
