@@ -9,12 +9,12 @@ use {
         skin::PanelSkin,
         task_sync::Dam,
     },
-    crossterm::{
+    crokey::crossterm::{
         cursor,
         style::{Color, Print, SetBackgroundColor, SetForegroundColor},
         QueueableCommand,
     },
-    memmap::Mmap,
+    memmap2::Mmap,
     once_cell::sync::Lazy,
     std::{
         fs::File,
