@@ -1,7 +1,7 @@
 use {
     super::*,
     crate::{
-        app::{Selection, SelInfo, SelectionType},
+        app::*,
         path,
     },
     ahash::AHashMap,
@@ -16,6 +16,9 @@ pub struct ExecutionStringBuilder<'b> {
     /// the current file selection
     pub sel_info: SelInfo<'b>,
 
+    /// the current root of the app
+    root: &'b Path,
+
     /// the selection in the other panel, when there are exactly two
     other_file: Option<&'b PathBuf>,
 
@@ -24,20 +27,25 @@ pub struct ExecutionStringBuilder<'b> {
 }
 
 impl<'b> ExecutionStringBuilder<'b> {
-    pub fn from_sel_info(
+    /// constructor to use when there's no invocation string
+    /// (because we're in the process of building one, for example
+    /// when a verb is triggered from a key shortcut)
+    pub fn without_invocation(
          sel_info: SelInfo<'b>,
+         app_state: &'b AppState,
     ) -> Self {
         Self {
             sel_info,
-            other_file: None,
+            root: &app_state.root,
+            other_file: app_state.other_panel_path.as_ref(),
             invocation_values: None,
         }
     }
-    pub fn from_invocation(
+    pub fn with_invocation(
         invocation_parser: &Option<InvocationParser>,
         sel_info: SelInfo<'b>,
-        other_file: &'b Option<PathBuf>,
-        invocation_args: &Option<String>,
+        app_state: &'b AppState,
+        invocation_args: Option<&String>,
     ) -> Self {
         let invocation_values = invocation_parser
             .as_ref()
@@ -45,14 +53,21 @@ impl<'b> ExecutionStringBuilder<'b> {
             .and_then(|(parser, args)| parser.parse(args));
         Self {
             sel_info,
-            other_file: other_file.as_ref(),
+            root: &app_state.root,
+            other_file: app_state.other_panel_path.as_ref(),
             invocation_values,
         }
     }
-    fn get_raw_capture_replacement(&self, ec: &Captures<'_>) -> Option<String> {
+    fn get_raw_replacement<F>(
+        &self,
+        f: F
+    ) -> Option<String>
+    where
+        F: Fn(Option<Selection<'_>>) -> Option<String>
+    {
         match self.sel_info {
-            SelInfo::None => self.get_raw_sel_capture_replacement(ec, None),
-            SelInfo::One(sel) => self.get_raw_sel_capture_replacement(ec, Some(sel)),
+            SelInfo::None => f(None),
+            SelInfo::One(sel) => f(Some(sel)),
             SelInfo::More(stage) => {
                 let mut sels = stage.paths().iter()
                     .map(|path| Selection {
@@ -61,10 +76,10 @@ impl<'b> ExecutionStringBuilder<'b> {
                         stype: SelectionType::from(path),
                         is_exe: false,
                     });
-                self.get_raw_sel_capture_replacement(ec, sels.next())
+                f(sels.next())
                     .filter(|first_rcr| {
                         for sel in sels {
-                            let rcr = self.get_raw_sel_capture_replacement(ec, Some(sel));
+                            let rcr = f(Some(sel));
                             if rcr.as_ref() != Some(first_rcr) {
                                 return false;
                             }
@@ -74,18 +89,56 @@ impl<'b> ExecutionStringBuilder<'b> {
             }
         }
     }
-    fn get_raw_sel_capture_replacement(
+    fn get_raw_capture_replacement(&self, ec: &Captures<'_>) -> Option<String> {
+        self.get_raw_replacement(|sel| {
+            self.get_raw_sel_capture_replacement(ec, sel)
+        })
+    }
+    /// return the standard replacement (ie not one from the invocation)
+    fn get_raw_sel_name_standard_replacement(
         &self,
-        ec: &Captures<'_>,
+        name: &str,
         sel: Option<Selection<'_>>,
     ) -> Option<String> {
-        let name = ec.get(1).unwrap().as_str();
+        debug!("repl name : {:?}", name);
         match name {
+            "root" => Some(path_to_string(self.root)),
             "line" => sel.map(|s| s.line.to_string()),
-            "file" => sel.map(|s| s.path).map(path_to_string),
-            "directory" => sel.map(|s| path::closest_dir(s.path)).map(path_to_string),
-            "parent" => sel.and_then(|s| s.path.parent()).map(path_to_string),
-            "other-panel-file" => self.other_file.map(path_to_string),
+            "file" => sel.map(|s| s.path)
+                .map(path_to_string),
+            "file-name" => sel.map(|s| s.path)
+                .and_then(|path| path.file_name())
+                .and_then(|oss| oss.to_str())
+                .map(|s| s.to_string()),
+            "file-stem" => sel.map(|s| s.path)
+                .and_then(|path| path.file_stem())
+                .and_then(|oss| oss.to_str())
+                .map(|s| s.to_string()),
+            "file-extension" => {
+                debug!("expending file extension");
+                sel.map(|s| s.path)
+                .and_then(|path| path.extension())
+                .and_then(|oss| oss.to_str())
+                .map(|s| s.to_string())
+            }
+            "file-dot-extension" => {
+                debug!("expending file dot extension");
+                sel.map(|s| s.path)
+                .and_then(|path| path.extension())
+                .and_then(|oss| oss.to_str())
+                .map(|ext| format!(".{}", ext))
+                .or_else(|| Some("".to_string()))
+            }
+            "directory" => sel.map(|s| path::closest_dir(s.path))
+                .map(path_to_string),
+            "parent" => sel.and_then(|s| s.path.parent())
+                .map(path_to_string),
+            "other-panel-file" => self.other_file
+                .map(path_to_string),
+            "other-panel-filename" => self.other_file
+                .and_then(|path| path.file_name())
+                .and_then(|oss| oss.to_str())
+                .map(|s| s.to_string()),
             "other-panel-directory" => self
                 .other_file
                 .map(|p| path::closest_dir(p))
@@ -95,7 +148,17 @@ impl<'b> ExecutionStringBuilder<'b> {
                 .other_file
                 .and_then(|p| p.parent())
                 .map(path_to_string),
-            _ => {
+            _ => None,
+        }
+    }
+    fn get_raw_sel_capture_replacement(
+        &self,
+        ec: &Captures<'_>,
+        sel: Option<Selection<'_>>,
+    ) -> Option<String> {
+        let name = ec.get(1).unwrap().as_str();
+        self.get_raw_sel_name_standard_replacement(name, sel)
+            .or_else(||{
                 // it's not one of the standard group names, so we'll look
                 // into the ones provided by the invocation pattern
                 self.invocation_values.as_ref()
@@ -117,8 +180,7 @@ impl<'b> ExecutionStringBuilder<'b> {
                             Some(value.to_string())
                         }
                     })
-            }
-        }
+            })
     }
     fn get_capture_replacement(&self, ec: &Captures<'_>) -> String {
         self.get_raw_capture_replacement(ec)
@@ -132,6 +194,55 @@ impl<'b> ExecutionStringBuilder<'b> {
         self.get_raw_sel_capture_replacement(ec, sel)
             .unwrap_or_else(|| ec[0].to_string())
     }
+    /// fills groups having a default value (after the colon)
+    ///
+    /// This is used to fill the input in case on non auto_exec
+    /// verb triggered with a key
+    pub fn invocation_with_default(
+        &self,
+        verb_invocation: &VerbInvocation,
+    ) -> VerbInvocation {
+        VerbInvocation {
+            name: verb_invocation.name.clone(),
+            args: verb_invocation.args.as_ref().map(|a| {
+                GROUP.replace_all(
+                    a.as_str(),
+                    |ec: &Captures<'_>| {
+                        ec.get(2)
+                            .map(|default_name| default_name.as_str())
+                            .and_then(|default_name|
+                                self.get_raw_replacement(|sel|
+                                    self.get_raw_sel_name_standard_replacement(default_name, sel)
+                                )
+                            )
+                            .unwrap_or_else(|| "".to_string())
+                    },
+                ).to_string()
+            }),
+            bang: verb_invocation.bang,
+        }
+    }
+
+    fn base_dir(&self) -> &Path {
+        self.sel_info
+            .one_sel()
+            .map_or(self.root, |sel| sel.path)
+    }
+
+    /// build a path
+    pub fn path(
+        &self,
+        pattern: &str,
+    ) -> PathBuf {
+        path::path_from(
+            self.base_dir(),
+            path::PathAnchor::Unspecified,
+            &GROUP.replace_all(
+                pattern,
+                |ec: &Captures<'_>| self.get_capture_replacement(ec),
+            )
+        )
+    }
     /// build a shell compatible command, with escapings
     pub fn shell_exec_string(
         &self,
@@ -217,7 +328,9 @@ mod execution_builder_test {
 
     use {
         super::*,
-        crate::app::SelectionType,
+        crate::{
+            stage::*,
+        },
     };
 
     fn check_build_execution_from_sel(
@@ -233,7 +346,15 @@ mod execution_builder_test {
             stype: SelectionType::File,
             is_exe: false,
         };
-        let mut builder = ExecutionStringBuilder::from_sel_info(SelInfo::One(sel));
+        let app_state = AppState {
+            stage: Stage::default(),
+            root: PathBuf::from("/".to_owned()),
+            other_panel_path: None,
+        };
+        let mut builder = ExecutionStringBuilder::without_invocation(
+            SelInfo::One(sel),
+            &app_state,
+        );
         let mut map = AHashMap::default();
         for (k, v) in replacements {
             map.insert(k.to_owned(), v.to_owned());
